==> cms-db_v0.9.tar.gz: contact.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	chdir('./admin');
	include('friendlyerror.firewall.inc.php');
	die();
}

chdir('./admin');
$locale = new LocalizingClass('contact', $locale_default);
chdir('../');

$mailpageid = $_SERVER['QUERY_STRING'];
$id_time = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$mailpageid.'1'));
$id_empty = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$mailpageid.'2'));

function displayContactForm($name = '', $mail = '', $subject = '', $text = '') {
	global $template, $urlbefore, $mailpageid, $urlafter, $id_empty, $id_time;

	$template->addToHead('<style type="text/css">/* <![CDATA[ */ .input_special { display: none } /* ]]> */</style>');

	$time = microtime(true);

	?>
	<form action="<?php echo $urlbefore.$mailpageid.$urlafter ?>" method="post">
		<p>
			<label for="mail_name"><strong><?php locale('label_name') ?></strong></label><br />
			<input type="text" name="name" id="mail_name" value="<?php echo htmlspecialchars($name) ?>" size="30" maxlength="50" /><br />
			<label for="mail_mail"><strong><?php locale('label_mail') ?></strong></label><br />
			<input type="text" name="mail" id="mail_mail" value="<?php echo htmlspecialchars($mail) ?>" size="30" maxlength="100" /><br />
			<label for="mail_subject"><strong><?php locale('label_subject') ?></strong></label><br />
			<input type="text" name="subject" id="mail_subject" value="<?php echo htmlspecialchars($subject) ?>" size="30" maxlength="100" /><br />
			<label for="mail_text"><strong><?php locale('label_message') ?></strong></label><br />
			<textarea name="text" id="mail_text" cols="60" rows="10" style="width: 100%"><?php echo htmlspecialchars($text) ?></textarea>
			<input type="text" name="<?php echo $id_empty ?>" value="" size="1" class="input_special" />
			<input type="text" name="<?php echo $id_time ?>" value="<?php echo $time ?>" size="1" class="input_special" />
		</p>
		<p>
			<input type="submit" name="CMS-DB_MAIL_SENT" value="<?php locale('button_send') ?>" />
			<input type="reset" value="<?php locale('button_reset') ?>" />
		</p>
	</form>
	<?php
}

if (!isset($_POST['CMS-DB_MAIL_SENT']) or !isset($_POST[$id_empty]) or !isset($_POST[$id_time])) {
	displayContactForm();
} else {
	include('./admin/escape.inc.php');
	$array = array("\n", "\r");
	$name = escapeSL($_POST['name']);
	$name = str_replace($array, '', $name);
	$mail = escapeSL($_POST['mail']);
	$mail = str_replace($array, '', $mail);
	$subject = escapeSL($_POST['subject']);
	$subject = str_replace($array, '', $subject);
	$text = escapeSL($_POST['text']);
	$text = str_replace("\r", '', $text);
	$text = wordwrap($text, 70);
	if($name != '' && $mail != '' && strpos($mail, '@') !== false && strpos($mail, '.') !== false && $subject != '' && $text != '') {
		$time_old = $_POST[$id_time];
		$time_now = microtime(true);
		$time_difference = $time_now-$time_old;
		/*
		 * Spam-Schutz:
		 * Feld darf nicht von "blödem" Bot ausgefüllt werden,
		 * mindestens 10 Sekunden zum Schreiben des Textes
		 */
		if ($_POST[$id_empty] == '' && $time_difference > 10) {
			mail(
				$mailaddress,
				'['.locale('desc_contactform',true).'] '.$subject,
				$text,
				'From: '.$name.' <'.$mail.'>'."\r\n".
				'Content-Type: text/plain; charset=utf-8'
			);
			echo '<p class="success">'.locale('desc_mail-sent',true).'</p>';
		} else {
			echo '<p class="error">'.locale('desc_error-spamprotection',true).'</p>';
			displayContactForm($name, $mail, $subject, $text);
		}
	} else {
		$errors = array();
		if ($name == '') $errors[] = locale('desc_error-missing-list-name',true);
		if (strpos($mail, '@') === false or strpos($mail, '.') === false) $errors[] = locale('desc_error-missing-list-mail',true);
		if ($subject == '') $errors[] = locale('desc_error-missing-list-subject',true);
		if ($text == '') $errors[] = locale('desc_error-missing-list-message',true);
		$errors = '<br />&bull; '.implode('<br />&bull; ', $errors);
		echo '<p class="error">'.locale('desc_error-input',true).' '.$errors.'</p>';
		displayContactForm($name, $mail, $subject, $text);
	}
}

unset($locale);
?>

==> cms-db_v0.9.3.tar.gz: contact.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	chdir('./admin');
	include('friendlyerror.firewall.inc.php');
	die();
}

$locale = new LocalizingClass('contact', $locale_default);

$mailpageid = $_SERVER['QUERY_STRING'];
$id_time = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$mailpageid.'1'));
$id_empty = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$mailpageid.'2'));

function displayContactForm($name = '', $mail = '', $subject = '', $text = '') {
	global $template, $urlbefore, $mailpageid, $urlafter, $id_empty, $id_time;

	$template->addToHead('<style type="text/css">/* <![CDATA[ */ .input_special { display: none } /* ]]> */</style>');

	$time = microtime(true);

	?>
	<form action="<?php echo $urlbefore.$mailpageid.$urlafter ?>" method="post">
		<p>
			<label for="mail_name"><strong><?php locale('label_name') ?></strong></label><br />
			<input type="text" name="name" id="mail_name" value="<?php echo htmlspecialchars($name) ?>" size="30" maxlength="50" /><br />
			<label for="mail_mail"><strong><?php locale('label_mail') ?></strong></label><br />
			<input type="text" name="mail" id="mail_mail" value="<?php echo htmlspecialchars($mail) ?>" size="30" maxlength="100" /><br />
			<label for="mail_subject"><strong><?php locale('label_subject') ?></strong></label><br />
			<input type="text" name="subject" id="mail_subject" value="<?php echo htmlspecialchars($subject) ?>" size="30" maxlength="100" /><br />
			<label for="mail_text"><strong><?php locale('label_message') ?></strong></label><br />
			<textarea name="text" id="mail_text" cols="60" rows="10" style="width: 100%"><?php echo htmlspecialchars($text) ?></textarea>
			<input type="text" name="<?php echo $id_empty ?>" value="" size="1" class="input_special" />
			<input type="text" name="<?php echo $id_time ?>" value="<?php echo $time ?>" size="1" class="input_special" />
		</p>
		<p>
			<input type="submit" name="CMS-DB_MAIL_SENT" value="<?php locale('button_send') ?>" />
			<input type="reset" value="<?php locale('button_reset') ?>" />
		</p>
	</form>
	<?php
}

if (!isset($_POST['CMS-DB_MAIL_SENT']) or !isset($_POST[$id_empty]) or !isset($_POST[$id_time])) {
	displayContactForm();
} else {
	include('./admin/escape.inc.php');
	$array = array("\n", "\r");
	$name = escapeSL($_POST['name']);
	$name = str_replace($array, '', $name);
	$mail = escapeSL($_POST['mail']);
	$mail = str_replace($array, '', $mail);
	$subject = escapeSL($_POST['subject']);
	$subject = str_replace($array, '', $subject);
	$text = escapeSL($_POST['text']);
	$text = str_replace("\r", '', $text);
	$text = wordwrap($text, 70);
	if($name != '' && $mail != '' && strpos($mail, '@') !== false && strpos($mail, '.') !== false && $subject != '' && $text != '') {
		$time_old = $_POST[$id_time];
		$time_now = microtime(true);
		$time_difference = $time_now-$time_old;
		/*
		 * Spam-Schutz:
		 * Feld darf nicht von "blödem" Bot ausgefüllt werden,
		 * mindestens 10 Sekunden zum Schreiben des Textes
		 */
		if ($_POST[$id_empty] == '' && $time_difference > 10) {
			mail(
				$mailaddress,
				'['.locale('desc_contactform',true).'] '.$subject,
				$text,
				'From: '.$name.' <'.$mail.'>'."\r\n".
				'Content-Type: text/plain; charset=utf-8'
			);
			echo '<p class="success">'.locale('desc_mail-sent',true).'</p>';
		} else {
			echo '<p class="error">'.locale('desc_error-spamprotection',true).'</p>';
			displayContactForm($name, $mail, $subject, $text);
		}
	} else {
		$errors = array();
		if ($name == '') $errors[] = locale('desc_error-missing-list-name',true);
		if (strpos($mail, '@') === false or strpos($mail, '.') === false) $errors[] = locale('desc_error-missing-list-mail',true);
		if ($subject == '') $errors[] = locale('desc_error-missing-list-subject',true);
		if ($text == '') $errors[] = locale('desc_error-missing-list-message',true);
		$errors = '<br />&#x2022; '.implode('<br />&#x2022; ', $errors);
		echo '<p class="error">'.locale('desc_error-input',true).' '.$errors.'</p>';
		displayContactForm($name, $mail, $subject, $text);
	}
}

unset($locale);
?>
